@@ -15,11 +15,6 @@ from gym.utils import EzPickle
 KERNEL_WINDOW_LENGTH = 2
 
 
-def get_image(path):
-    image = pygame.image.load(path)
-    return image
-
-
 def deg_to_rad(deg):
     return deg * np.pi / 180
 
@@ -133,8 +128,7 @@ class PaddleSprite(pygame.sprite.Sprite):
 
 
 class BallSprite(pygame.sprite.Sprite):
-    def __init__(self, randomizer, dims, speed, bounce_randomness=False):  # def __init__(self, image, speed):
-        # self.surf = get_image(image)
+    def __init__(self, randomizer, dims, speed, bounce_randomness=False):
         self.surf = pygame.Surface(dims)
         self.rect = self.surf.get_rect()
         self.speed_val = speed
@@ -284,13 +278,13 @@ class CooperativePong:
             # sets self.renderOn to true and initializes display
             self.enable_render()
 
-        observation = pygame.surfarray.pixels3d(self.screen)
+        observation = np.array(pygame.surfarray.pixels3d(self.screen))
         if mode == "human":
             pygame.display.flip()
         return np.transpose(observation, axes=(1, 0, 2)) if mode == "rgb_array" else None
 
     def observe(self):
-        observation = pygame.surfarray.pixels3d(self.screen)
+        observation = np.array(pygame.surfarray.pixels3d(self.screen))
         observation = np.rot90(observation, k=3)  # now the obs is laid out as H, W as rows and cols
         observation = np.fliplr(observation)  # laid out in the correct order
         return observation
