@@ -20,10 +20,10 @@ def env(**kwargs):
 
 class raw_env(RLCardBase):
 
-    metadata = {'render.modes': ['human'], "name": "leduc_holdem_v2"}
+    metadata = {'render.modes': ['human'], "name": "leduc_holdem_v4"}
 
-    def __init__(self):
-        super().__init__("leduc-holdem", 2, (36,))
+    def __init__(self, num_players=2):
+        super().__init__("leduc-holdem", num_players, (36,))
 
     def render(self, mode='human'):
         for player in self.possible_agents:
