@@ -4,11 +4,10 @@ from pettingzoo.utils.conversions import parallel_wrapper_fn
 
 
 class raw_env(SimpleEnv):
-    def __init__(self, num_good=2, num_adversaries=4, num_obstacles=1, num_food=2, max_cycles=25):
+    def __init__(self, num_good=2, num_adversaries=4, num_obstacles=1, num_food=2, max_cycles=25, num_forests=2, continuous_actions=False):
         scenario = Scenario()
-        num_forests = 2  # crahes with any other number of forrests
         world = scenario.make_world(num_good, num_adversaries, num_obstacles, num_food, num_forests)
-        super().__init__(scenario, world, max_cycles)
+        super().__init__(scenario, world, max_cycles, continuous_actions)
         self.metadata['name'] = "simple_world_comm_v2"
 
 
